[polly] r307800 - [NFC] [SCEVValidator] Make parameter name of `hasScalarDepsInsideRegion` consistent.

Siddharth Bhat via llvm-commits llvm-commits at lists.llvm.org
Wed Jul 12 08:32:30 PDT 2017


Author: bollu
Date: Wed Jul 12 08:32:30 2017
New Revision: 307800

URL: http://llvm.org/viewvc/llvm-project?rev=307800&view=rev
Log:
[NFC] [SCEVValidator] Make parameter name of `hasScalarDepsInsideRegion` consistent.

`SCEV` parameter is called as `Expr` in `SCEVValidator.cpp`, as well
as in other functions in `SCEVValidator.h`.

Modified:
    polly/trunk/include/polly/Support/SCEVValidator.h

Modified: polly/trunk/include/polly/Support/SCEVValidator.h
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/include/polly/Support/SCEVValidator.h?rev=307800&r1=307799&r2=307800&view=diff
==============================================================================
--- polly/trunk/include/polly/Support/SCEVValidator.h (original)
+++ polly/trunk/include/polly/Support/SCEVValidator.h Wed Jul 12 08:32:30 2017
@@ -65,12 +65,12 @@ void findValues(const llvm::SCEV *Expr,
 /// Returns true when the SCEV contains references to instructions within the
 /// region.
 ///
 /// @param S The SCEV to analyze.
 /// @param R The region in which we look for dependences.
 /// @param Scope Location where the value is needed.
 /// @param AllowLoops Whether loop recurrences outside the loop that are in the
 ///                   region count as dependence.
-bool hasScalarDepsInsideRegion(const llvm::SCEV *S, const llvm::Region *R,
+bool hasScalarDepsInsideRegion(const llvm::SCEV *Expr, const llvm::Region *R,
                                llvm::Loop *Scope, bool AllowLoops);
 bool isAffineExpr(const llvm::Region *R, llvm::Loop *Scope,
                   const llvm::SCEV *Expression, llvm::ScalarEvolution &SE,
@@ -65,12 +65,12 @@ void findValues(const llvm::SCEV *Expr,
 /// region.
 ///
-/// @param S The SCEV to analyze.
+/// @param Expr The SCEV to analyze.
 /// @param R The region in which we look for dependences.
 /// @param Scope Location where the value is needed.




More information about the llvm-commits mailing list